Afrikaans
Akan
Albanian
Amharic
Arabic
Armenian
Azerbaijani
Basque
Belarusian
Bemba
Bengali
Bihari
Bosnian
Breton
Bulgarian
Cambodian
Catalan
Cebuano
Cherokee
Chichewa
Chinese (Simplified)
Chinese (Traditional)
Corsican
Croatian
Czech
Danish
Dutch
English
Esperanto
Estonian
Ewe
Faroese
Filipino
Finnish
French
Frisian
Ga
Galician
Georgian
German
Guarani
Gujarati
Haitian Creole
Hausa
Hawaiian
Hebrew
Hindi
Hmong
Hungarian
Icelandic
Igbo
Indonesian
Interlingua
Irish
Italian
Japanese
Javanese
Kannada
Kazakh
Kinyarwanda
Kirundi
Kongo
Korean
Krio (Sierra Leone)
Kurdish
Kurdish (Soranî)
Kyrgyz
Laothian
Latin
Latvian
Lingala
Lithuanian
Lozi
Luganda
Luo
Luxembourgish
Macedonian
Malagasy
Malay
Malayalam
Maltese
Maori
Marathi
Mauritian Creole
Moldavian
Mongolian
Myanmar (Burmese)
Montenegrin
Nepali
Nigerian Pidgin
Northern Sotho
Norwegian
Norwegian (Nynorsk)
Occitan
Oriya
Oromo
Pashto
Persian
Polish
Portuguese (Portugal)
Punjabi
Quechua
Romanian
Romansh
Runyakitara
Russian
Samoan
Scots Gaelic
Serbian
Serbo-Croatian
Sesotho
Setswana
Seychellois Creole
Shona
Sindhi
Sinhalese
Slovak
Slovenian
Somali
Spanish
Spanish (Latin American)
Sundanese
Swahili
Swedish
Tajik
Tamil
Tatar
Telugu
Thai
Tigrinya
Tonga
Tshiluba
Tumbuka
Turkish
Turkmen
Twi
Uighur
Ukrainian
Urdu
Uzbek
Vietnamese
Welsh
Wolof
Xhosa
Yiddish
Yoruba
Zulu
[Static buzzing]
♪
♪ Hey, everybody, have you heard the news? ♪
♪ Joe Bob is back in town ♪
♪ He's over at the Drive-In ♪
♪ hanging around, watching crazy movies ♪
♪ So come on down ♪
♪ To Joe Bob's Last Drive-In Show ♪
♪ Blood, beasties, boobies, and more ♪
♪ Joe Bob's Last Drive-In Show ♪
♪ It's a spooky good time with monsters and ghosts ♪
♪ Crazy, kooky fun with the world's greatest host ♪
♪ Joe Bob's Last Drive-In Show It's gonna be legendary ♪
♪ Joe Bob's Last Drive-In Show It's gonna be very scary ♪
♪ Joe Bob's Last Drive-In Show ♪
♪ Let's go ♪
♪
[Wind blows]
♪
[Static buzzes]
♪
♪
-Welcome to "Joe Bob's Cold, Cruel Christmas,"
our annual holiday special on "The Last Drive-In."
We have a couple of icy, cold, frostbitten,
'80s slashers for you tonight.
Because it was a cold, cruel year for a lot of people.
And so we wanted to make things worse.
-Ah! That's terrible.
-Well, you know how horror works, Darcy.
You watch horror. Aah.
[Darcy laughs]
As comfort food --
to avoid the real horror that's pecking at your window.
-You really think 2025 was that bad?
-Well, 2025 was great for some people and bad for others,
but it was mostly great for the people who were already okay.
And bad for the people who were trying to get to the okay milestone.
-Fair.
-You know, all those people we know at the shows
and the conventions and the people
who order the videos to send to their cousin
who just lost his job,
and the aunt whose mother died and the couple getting married,
who can't afford a decent apartment in Sarasota.
Those people.
-Why Sarasota?
-I don't know, people in Florida get kicked around a lot.
I heard a lot of Florida stories this year.
-This is not your normal Christmas attitude, though.
-No, it is not my normal Christmas attitude.
But it's Christmas, so we're gonna be happy, right?
And for my annual Christmas message,
You know how this works, right?
-Yes, I do.
-Normally I retell the Christmas story in Bethlehem,
and then we single out some aspect of the story.
And that's the theme leading into our Christmas auction,
where we raise money for our four charities.
And those charities always represent the people
inside the stable at Bethlehem on Christmas Eve.
We have one charity for women. 'Cause of Mary,
one charity for children because Baby Jesus,
one charity for animals 'cause of that donkey.
You know, the woman was nine months pregnant,
had to ride 90 fucking miles on that donkey.
You know, so we honor them.
And then one charity for the forgotten, the poor,
the homeless, the left out part of the population.
'Cause that's why the miracles happen
in the stinky part of the house.
'Cause that's what it's all about.
It's about bringing hope into the world, right?
-A stinky part of the house?
-Well, yeah, 'cause that stable...
Uh, that was just actually where the family keeps the animals,
you know, it's like a cluttered garage
where Dad keeps rusty jumper cables and stacks
of old National Geographics. So you feed the donkey there.
And by the way,
if you're not Christian, we're not leaving you out.
Jesus' family was Jewish, of course.
And the place where this happened,
the Roman colony of Judea had a lot of non-Roman minorities,
like Greeks and Syrians and Idumaeans and Nabataeans,
and nobody cares about the Idumaeans and the Nabataeans
'cause nobody remembers who they were, but...
-That's way off topic.
-Yeah, I know, but my point being,
if you're Muslim or Buddhist or what's the one in Iran?
Bahá'í? Zoroastrian? Is that the same thing?
Bahá'í and Zoroastrian -- or Hindu or whatever you are, atheist.
This is still gonna make sense, okay?
But since it's Christmas, I'm gonna do the Christmas story.
-Let's do it.
-But I just want to make it clear that we're --
What do you call it when you include everyone?
-Nice. [Laughter]
-Well, yeah, but universalist, I think, is the official term.
The horror community accepts everybody.
We have bikers. We also have skateboarders.
We also have downhill skiers, so... -Crazy.
-And speaking of downhill skiing,
I thought you were gonna put on a ski suit!
-I did! This is a --
-Is that a ski suit?
-It is to me. And I got boots.
Ski boots. -Oh, come on.
You're gonna freeze your butt off
when we hit the slopes tonight.
-The slopes of Coweta County?
-Yeah, the slopes of Coweta County, Georgia.
-Whoo!
-But right now, I want to talk about Joseph,
the dad in the Christmas story.
Joseph had every dirty job in the Christmas story.
First of all, his wife is pregnant
and they've never had sex.
He's got to be thinking, "Yeah,
I think I understand what's going on here,
but damn. I mean, is the kid even mine
once we get it?"
But he has to put all that out of his mind,
'cause, you know,
why is he schlepping everything 90 miles
in the first place from Nazareth to Bethlehem?
'Cause the government says he has to register
for the census in his family towns
so they can tax him properly.
He's basically going on a 90 mile hike
through rough country full of wild animals
with a pregnant woman,
harsh weather, no place to pee most of the time,
he's losing money from not being
able to run his carpentry business back in Nazareth.
His family in Bethlehem has no place for him to sleep
once he gets there, and he's doing it all
so the tax collector will know how to find him.
Are you kidding me?
And then the tax rate is probably gonna be 50% on him 'cause he's a Jew.
So my point is the Roman Empire at this time
was run by billionaires.
The emperor was a billionaire.
The senators were billionaires.
Herod, the local client king, he was a billionaire.
And as long as they liked you and you were Roman,
you could have a nice life.
If they didn't like you,
you could be jailed, flogged, killed by the military,
left by the side of the road as a warning to others.
The soldiers had no loyalty to anybody except the Emperor,
nor did the senators.
They pretty much did whatever the emperor wanted
so they could keep their wealth and their status.
And the result was that people like Joseph
were just regarded as losers.
They were just the people that you taxed
to pay for the new stadium, or the new palace,
or the standing army
that put down the occasional revolt among Jews
who made the mistake of refusing to do what they were told.
So there was no free speech. If you insulted the emperor,
that could result in the death penalty.
It was a brutal government that on the surface
it looked like fun.
They're building stuff. They're building pleasure domes
and athletic fields and castles and fortresses.
But it was really built on racism,
oppression of foreigners, and contempt for the poor
and the physically disabled.
And all those cities they built,
the ones that eventually crumbled into nothing,
created huge environmental havoc.
They used up all the wood and the stone and the water
without any thought to replacing it.
And just to remind you of who was in charge,
they put these Roman soldiers everywhere,
so you would know that they don't just defend the country
against foreign invasion,
they defend the rulers of the country against you .
So what does Joseph do as one of the losers?
He walks that 90 miles with his pregnant wife.
He registers for the census.
He pays the tribute to Rome.
He pays the temple tax to Jerusalem.
He pays the market tax.
He pays the agriculture tax on the subsistence garden
that he has to feed his family.
He pays all the road tolls.
He's kind to those Roman soldiers
stationed along the road.
He follows the biblical doctrine of giving to the poor,
even though he's poor himself.
And he waits on outside help.
And the political landscape is so bleak
that the only outside help he can wait on
is divine intervention.
And then the baby Jesus is born.
Hope enters the world.
Not in Herod's castle, not in the emperor's palace,
not in the Roman style stadiums
that they're building in Galilee with all that tax money.
Hope enters the world in the stinky place
where it's hard to sleep.
The people who have closely followed this show
for the last seven years are very generous with the way
that they share their lives with me, you know?
Quite a few of those people,
the Mutant Family, lost their jobs this year.
Or they got downsized.
You know, I come from a family of federal employees,
so I know why people take those jobs.
They can make more money in the private sector,
but they trade financial success for security
and the feeling of patriotism
that comes with even the most menial
of United States government positions.
Well, a lot of those federal employees were fired,
replaced, forced out, told they were useless.
And then "The Last Drive-In" also has a big military following, okay?
I've got enormous respect for the military,
all branches of the military, and especially the US Marine Corps.
They really do protect us, night and day.
Those tough sons of bitches at Camp Lejeune,
they are ready to go anywhere in the world at any time.
They are physically ready, emotionally ready.
Their training is the best in the world.
They are fearless. They are committed.
And I know 'cause we have so many of them that are fans,
some of them felt they were used in ways
they didn't sign up for this year.
Sometimes to intimidate people
and that made for a bad year for them.
"The Last Drive-In" has a lot of viewers in farming communities.
Some of those communities were shaken to the core this year
by new shocks that caused them to have trouble keeping their crops moving
to, often to foreign destinations
and in some cases, it caused crops to rot in the fields.
And I can't even begin to list all the slings and arrows
that rattled the people that we know
that were living alternative lifestyles.
And then -- this is the other half of my family, the teachers.
And it really, it's probably 30% of the Mutant Family
is teachers of one sort or another.
Educational institutions in general were told,
Pay for it yourself, you're getting no more help."
And thank God, in many cases they were able to do that
'cause people will still step up and do the right thing
when kids are involved.
So not a good year for the Mutant Family,
but a year when what we were called on to do
is follow the example of Joseph. Because you're poor,
you help the ones who are even poorer than yourself.
So that's what the Christmas auction is all about this year.
Let me use a more American example than Bethlehem.
In John Steinbeck's novel "The Grapes of Wrath" --
people still read that book?
I don't think people read that book anymore.
Anyway, in this novel called "The Grapes of Wrath,"
written by John Steinbeck,
the Joad family has to flee Oklahoma
because of the Dust Bowl,
and they go from migrant camp to migrant camp
on their way to California.
Then California turns out to be not much better than Oklahoma
'cause it's full of hostility and cruel law enforcement types
and new hardships.
And so the matriarch of the family, Ma Joad,
she's looking back on all they've been through,
everywhere they've lived, where people were sick
and hungry and desperate, and she says,
"If you're in trouble or hurt or in need, go to the poor people.
They're the only ones that'll help."
The only ones that'll help.
And that's why this year we're doing
the Christmas auction a little differently.
The mutants are hurting, but the mutants are reaching out.
First of all,
we have five charities instead of the usual four,
but all the charities are organizations
that got nuked in one way or another
by the crazy chaos of 2025.
And anything you buy in the Christmas auction,
or if you can't afford the auction,
you can buy one of our premium items.
We have a Christmas special T-shirt.
We have a Christmas special hoodie.
We have a Christmas special humongous drinking mug,
it's the biggest mug I've ever seen in my life.
Anyway, whatever you spend, 100% of that money
goes to the following charities.
Our children's charity this year is
the Elizabeth Glaser Pediatric Aids Foundation.
Why? Because in February
they got a letter saying their grants were terminated
for 10,000 children and 10,000 pregnant women.
So 20,000 lives endangered overnight.
Our animal charity for this year
is the Xerces Society for Invertebrate Conservation,
which works to protect endangered species
that nobody else cares about.
Why do they need help?
'Cause one third of their budget was terminated
once again, overnight by the government,
apparently because they worked to reduce the use of pesticides
that kill off the endangered species.
Our charity for women this year is the Women's Advocacy Center,
which helps survivors of domestic abuse.
'Cause listen to this -- an estimated 680,000 women and children
are now without support services
because of funds that were frozen or withdrawn,
the funds that keep domestic violence shelters open.
And as we know from the past, when you close shelters,
the death rate goes way up.
So grants for the Violence Against Women Act
have been reduced by 38%
in a year that's seen a 50% increase in housing help requests.
Another way to say housing help request would be
screams to be rescued
in a year that saw a 15% increase in calls to the hotline.
And our fourth category, as usual,
is our charity for the disenfranchised,
the left out, the powerless.
And we have two of those this year
'cause there were a lot of powerless people out there
trying to deal with things out of horror,
out of horror movies, really.
The first charity is Catholic Relief Services,
which works on behalf of refugees.
All the grants got cut off, impacting not just a few people,
but literally millions of homeless people
in various locations all over the world.
The people who run the -- it's an American organization --
the people who run it had to report to the Pope
that food was rotting in warehouses
and that vulnerable people were gonna starve,
and that services for the sick
and the malnourished children that rely on them
were gonna be affected in more than 100 countries.
And finally, our fifth charity, Meals on Wheels,
in total limbo
because of congressional cuts and executive cuts.
Seniors have been literally left without any way to eat.
I'm not even gonna go into the details of this,
but it's pathetic
that America has turned its back on the elderly.
This is classic widows and orphans stuff.
This is picking on sick people,
lonely people, and disabled people.
Okay, so we're going to help where we can order a shirt,
bid on an auction item, go to our website,
see what can be done.
And I promise, the rest of tonight's show
won't be as sobering as the remarks I have just made.
It's just that I know our audience,
and I know our audience will help. If you ask them to help, they do help.
Okay. Darcy. -Yeah. -I'm sorry. I'm sorry I did that this year.
-It's all good. -But it is a cold, cruel Christmas. What can I say?
But right now, we're gonna lighten things up
with some serial killer carnage in the snow.
-Yeah. -And our first movie.
Our first movie has been called, a writer for Dread Central
called this movie "The ultimate forgotten slasher,"
although that's been a while back,
so it's not quite so forgotten anymore.
But the movie is "Curtains"
and it's a mess of a movie, but it's a fun mess.
It was filmed in 1980. It was shelved for two years.
It was filmed again in 1982, even before they released it.
And the two versions by two different directors
were kind of fused together into what we have today
with one kill scene that always makes everybody's top ten.
Plus lots of quirky plot twists,
and we do love those at "The Last Drive-In."
And hey, some amazing performances by the likes
of Samantha Eggar, genuine movie star,
and John Vernon, genuine movie star
in exploitation land.
And if you've never seen "Curtains" before,
I'll just say it is the best movie
about psycho actresses fighting for a part in a movie
since the casting couch was invented.
And when was that, Darcy?
When was the casting couch --
-When was the casting couch invented? I don't know.
-Yeah. -I don't know.
-It's called a couch. They don't say the casting bed.
They say couch. I always envision one of those benches, you know,
that has a high back on one side and it's low on the other.
Chaise lounge, I guess, is what they mean with the casting couch.
It's a chaise lounge.
-No, I think what you're talking about
is a fainting couch. -A fainting couch?
-Mm-hm. -Well, that's got to be 19th century then.
French ladies passing out from tight corsets, stuff like that.
-Actually, that is true.
That's one thing that was used for. -Okay.
It was not. -It was! Look it up.
I promise. Fainting couch. -Okay.
So the casting couch -- if it's a fainting couch --
goes way back before movies were even invented.
So this movie is about a casting couch
and a sort of casting gladiatorial combat arena.
You need to be good at sex and violence
to survive in this movie.
Plus, you have to be able to act.
And, um, I'm trying not to do spoilers here
'cause I want first timers to experience the many
What-the-fuck changes in direction this movie takes.
So I'm gonna go ahead and do Drive-In Totals
without the usual synopsis. -Good plan.
-Alright, we have -- 8 Dead Bodies,
3 Breasts, Knife to the Belly,
Sickle to the Shoulder,
Sickle to the Throat, Head in the Toilet,
Supervised Breast-Fondling, Extended Jacuzzi Aardvarking,
1 Kinky Sex Game I'm Not Allowed to Describe Accurately,
Professional Headshot Immolation,
Extended Prop Storage Facility Cat-and-Mouse,
Closeup Sickle-Sharpening,
1 Excellent Old Hag Mask,
1 Slow Descent into Madness,
1 Commitment to Method Acting,
--and when I say commitment, I mean that literally --
Gratuitous Creepy Doll, Gratuitous Ice Skating,
Gratuitous Modern Dance, 2 Heads Roll,
Stand-Up Comedy Fu,
Drive-In Academy Award nominations for John Vernon
as the director from Hell
for saying, "Give the people what they want to believe.
It's part of their profession."
Samantha Eggar as the older actress being passed
over for saying, "I don't want to talk, I want to act."
Linda Thorson as the older,
but not quite so old actress for saying,
"I don't read without an offer."
Lesleh Donaldson as the ice skating ingenue for saying,
"Guess you got to want it more than being loved."
And Lynne Griffin as the stand-up comic for saying,
"Have you ever wanted anything so badly you'd do anything for it?"
Three and a half stars. Joe Bob says, "Check it out."
[Harmonica music]
And Darcy. -Yes.
-I appreciate it that when I threw in that totally off the subject reference
to the Idumaeans and the Nabataeans,
you did not scold me for that.
-I didn't have to.
-Well, that's very refreshing.
-'Cause no one knew what you were talking about
and then you moved on without explaining.
So we like that. -Okay.
Well, I could have said that
the Idumaeans and the Nabataeans, actually, uh...
-I feel like you should quit while you're ahead.
-Okay, but I'm just gonna say one thing about it.
When I was imagining how people treated Joseph,
I was looking for other ethnic groups
that the Romans hated as much as they hated the Jews.
Maybe hated is too strong a word, but, you know,
people that got hassled all the time.
-And you found two other groups?
-No, really. The Jews won.
Nobody came close to what happened to the Jews.
-I wouldn't think so.
-But the Nabataean god was Dushara.
-You said you wouldn't do this.
-And the Romans did not care about Dushara.
You could worship Dushara all you wanted.
The Romans said, "Go ahead. Dushara. Fine."
-Okay. Thank you. -He had a beard.
-Cool. -And he liked wine.
-That's awesome.
-He's dead. -Good.
[Laughter]
-Big Briggs here.
Back on the attack with a knack for bric-a-brac
to pack a six stack in Santa's sack.
And you can quote me on that.
This year, I'm selling this, that, and the other thing.
With all proceeds going to charity.
Just head to coldcruelchristmas.com
and bid on these items or donate directly.
So first up is these trusty drive-in speakers.
These sexy steel beauties once provided state-of-the-art
surround sound.
A little elbow grease,
you can probably get 'em working again.
It's a perfect family project.
Just clip one behind you, one in front of you,
and suddenly you are wrapped in a blanket of crystal clear,
buttery sound waves sure to please the audiophile
in the back seat of your compact hatchback or your station wagon.
Don't like sound? Got no ears?
Then put your peepers on this Spirit of '76 black and white Zenith television.
Screen used in seasons six and seven of "The Last Drive-In,"
this patriotic boob tube celebrates the bicentennial of the US of A.
There is a minuteman tattooed right on the side here,
hallucinating the Declaration of Independence
as he scans the horizon for British insurgents.
So bid now to watch your favorite flick
in monochromatic American bliss.
The cathode rays bursting through air
will give proof through the night
that our flag was still there.
Buy my stuff for charity. Do it for your fellow man.
-Visit our new location.
Exit 42 on the Motor Mile.
♪
[Wind blowing]
[Static buzzes]
♪
♪
♪
♪
[Metallic slash]
♪
-Not again.
Not ever again.
You've betrayed me for the last time.
God, I was such a fool. A woman in love.
No more.
I wouldn't bother to kill you,
except I'm so looking forward to every last ounce of blood
seeping out of your wretched body.
If I believed in demons, I'd damn your soul forever.
I'd put a stake through your heart,
if only you had one, you bastard.
[Gun clicks]
I just wish that I could do to you what you did to me.
This will have to do.
[Gun fires]
-I don't believe it.
[Laughs]
-No? -No.
Audra could never pull the trigger.
-A woman discovering her lover in bed with someone else?
You don't know much about women --
or love.
Or me.
♪
Well, what do you think?
I mean, I...
I know it needs work.
The lighting will help. The camera moves.
[Light pops]
Stryker?
Stryker.
♪
♪
[Gravel crunching]
♪
♪
♪
♪
-May I help you?
-We're here to see Doctor Pendleton.
-Have you got an appointment?
-He's expecting us.
-Your name?
-Stryker.
-There's a Mr. Stryker and a lady to see Doctor Pendleton.
-[Indistinct] Samantha Sherwood, you know.
-Yeah, I knew that.
Uh, the doctor will see you right away.
It's the first room on the right, just down the corridor.
Excuse me, Miss Sherwood --
may I have your autograph?
-Some other time.
-Oh, Jonathan.
-Arthur. -It's good to see you again.
-Good to see you.
Samantha, this is Dr. Arthur Pendleton.
-Hello. Won't you sit down?
Well now, everything seems to be in order.
I spoke with Dr. Harrison and he confirmed what you told me, Jonathan.
-So we're all set?
-Yes, I just need a couple of signatures.
Now, if you'll sign here.
-All right.
-It's an honor to have you here, Miss Sherwood.
I'm a long time fan of yours.
I am looking forward to seeing "Audra."
-The film has been shelved -- temporarily.
-I didn't realize.
Oh, I need one signature from you, Miss Sherwood.
If you'd sign here.
That's it.
I must say, Miss Sherwood, from Dr. Harrison's report,
I, uh, expected somewhat more severe behavior from you.
But I see no reason why you shouldn't be back in front of the camera in no time.
-Those days are over, Doctor. I only hope she fi--
♪ Samantha!
-Attendant! Get in!
♪
-Let go of me! Let go of me, I say!
Let go of me! Let go of my hands!
Let go of me! What are you --
Don't do this! Wait!
[Indistinct shouting]
What are you doing?!
God! Damn it!
-That's it. Set her down over there.
Good.
[Exhales]
-You all right? -Yeah.
-Now I see what you mean.
I think you should leave now.
-Doctor, I'd like to have a moment alone with her, if I may.
-Do you think that's wise? -Well, look at her.
What harm could she do me or anyone else like that?
-All right. We'll be outside if you need us.
Come with me.
[Both laughing]
-Audra herself couldn't have done it better.
-I think that poor doctor was in shock.
-He's not the only one. -Are you all right, darling?
-You almost took my head off.
-Well, the thought did occur to me.
-What a performance. -Oh, method acting.
You have to believe it to do it. -Well, I'm convinced.
Listen, do you really think this whole charade is necessary?
-Well, if I'm going to play a madwoman,
I've got to know what it's really like.
-But don't you think this is going a bit too far?
-[sighs] Call it research.
-Ah. All for the sake of a role in a film.
-All for the sake of getting it right.
And you, as my director, you should applaud my dedication.
You better go. -I like you like this.
-Oh, yes?
What sort of women have you been seeing lately?
-None like you. [Samantha laughs]
♪
♪
[Patient humming]
[Humming continues]
[Door bangs shut]
[Humming resumes]
[Patient mumbling, sobbing]
[Patient laughs]
♪
-Aah! [laughing]
[Giggling]
Ooh! [laughing]
-Samantha. You look beautiful.
-Stick to directing, Jonathan. You make a terrible actor.
-I missed you, too.
-I believe you.
-Why so defensive?
-Come on, Jonathan,
get enough psychiatric babble in here as it is.
-Doctor Pendleton said that you're doing well.
-Crazier than ever.
It's what you wanted, isn't it?
[Patient screaming]
[Whimpering]
[Moaning]
[Crying]
-People here tonight.
-Alice, what a pretty dress!
Never seen you wear that one before.
-Oh, it's nothing.
Don't get too many chances to wear it here.
-It's pretty.
May we dance?
[Wild laughter]
[Laughter echoing]
-I like the look. It's very convincing.
-They believe it.
They believe everything.
-Are they all so vacant?
-The sane ones.
That's how you get by in here.
-Well, you can drop all this in front of me.
Relax. Save it for the film.
-So sad.
-What is? -Even their laughter's sad.
Makes you cry.
[Patient shrieking]
[Shrieking continues]
♪
♪
[Patient humming]
♪
♪
♪
[Bell dings]
♪
♪
♪
♪
♪
[Flames crackle]
[Cheers and applause]
-Have you ever wanted something
so badly you would do anything for it?
[ Laughter ]
Well, me, I wanna be an actress.
[Laughter]
I mean, I wanted to be in pictures so badly I screwed a guy from Fotomat.
[Laughter]
You know when they say, "In and out in 24 hours?"
He was in and out in 24 seconds.
[Laughter]
I am off to a casting session.
[Laughter, exclamations]
Don't you wish you were going to be there with me? [laughs]
Now, kind of imagine this --
six actresses going to the same house
to audition for the same part.
[Laughter]
Well, it sounds like a lot of fun if you like bloodbaths.
I mean, I can see it now, the actor saying to me,
"Excuse me, but I think that's my knife in your back."
[Cheers and applause]
[Applause echoing]
[Flames crackling]
-So you'll audition for Stryker.
-Look, who does he think he is?
I mean, God, who does he think I am?
-Relax, lady. Okay, the man has strange ways, but he gets it done.
Have you seen the script?
-It's here somewhere.
-Did you read it?
-I don't read without an offer!
-Brooke! Jesus, Brooke!
I mean, if you wait for an offer from Stryker,
we'll both starve to death.
-Fuck you! You're the agent. Get me one.
-It was all I could do to get you the audition, dear.
-What you do for me is cash my checks.
Nice work if you can get it, Monty.
-Just go see the man, okay?
-God, I look like shit.
-I should look so bad.
Have you seen the trades? -The trades?
-Yes. Have you -- have you seen Friday's Variety, dear?
-You know I never read that crap.
-Right. Uh, Jonathan Stryker said
that there was only one actress in the world
who he'd consider for Audra.
You, cuckoo-head!
-He said that about me?
-Yes, of course he did!
Well, not in so many words,
but that was the general gist of the thing.
-But I thought Samantha Sherwood was playing Audra.
-Samantha Sherwood?!
Health problems.
You're the one.
[Flames crackle]
-Samantha: Bastard.
I still can't believe Stryker left me in the asylum.
If you hadn't sent Variety,
I never would have known he was going ahead without me anyway.
-Woman: I figured you'd be upset.
What are you going to do now?
♪
-Whatever I have to do to get it back.
♪
-Woman: Well, aren't you in enough trouble already?
By now, they're bound to know you've escaped.
-Let them come after me.
What I have to do won't take long.
-Woman: Why don't you just forget about it?
-That's the one thing I'll never do.
-Woman: I didn't help you get out to see you thrown back in again.
-Why did you? -Woman: You're my friend.
I felt sorry for you.
-Samantha: Stryker's the one you should feel sorry for.
This time, he's gone too far.
[Flames crackling]
[Classical music playing]
♪
♪
♪
♪
♪
♪
[Suspenseful music plays]
♪
♪
[Classical music continues]
♪
♪
♪
[Suspenseful music plays]
♪
[Classical music continues]
♪
♪
[Suspenseful music plays]
♪
[Classical music continues]
♪
♪
[Suspenseful music plays]
♪
[Classical music continues]
♪
♪
[Suspenseful music plays]
♪
♪
[Classical music continues]
♪
♪
[Suspenseful music plays]
♪
[Classical music continues]
♪
♪
♪
[Script thuds]
[Dramatic music plays]
♪
[Struggling]
♪
♪
[Sobbing]
♪
[Exhales]
[Both laugh]
♪
-Well, you didn't put up much of a fight.
-I didn't want to run my stocking.
[Both panting]
This is getting a little boring.
-Well, there's always the pizza boy.
-[laughs] No. Too messy.
Besides, the pepperoni always sticks to my ass.
-That's the only way to keep it warm.
What about Pac-Man? -What's that?
-Well, depressed spinster by a home video game. She takes it.
That night, the monster comes alive and eats everything in its way.
-Not tomorrow night, he doesn't.
-Well, he's easy. How about Saturday?
-Sunday. Keep the little guy warmed up.
-Why? Are you going somewhere?
-Told you, this weekend is Stryker's casting session.
-What kind of an audition is that?
The guy invites six women up to his house and calls it work.
-At least he's original.
-I wish you wouldn't go. -I want the part.
-More than you want my part? [She laughs]
-Don't be silly. Much more than I want your part.
-Be funny if it weren't true.
-I won't pass up this chance.
-Might not be here when you get back.
-Well, then I just better give you something to remember me by.
♪
-You mean straight? No games?
I'm just me and you're just you?
Reality. That's different.
[Static buzzes]
-Okay, welcome back to "Joe Bob's Cold, Cruel Christmas."
And who could be colder and crueler than people
in the film business
and specifically actresses competing for the same part.
But the coldest and cruelest character of them all
is Jonathan Stryker, the director
played by the great John Vernon.
Now, somebody told me that out of the 250
or so movies that John Vernon made,
there was one movie where he was a sweet, sympathetic guy,
but I don't remember the name of it,
and I don't know anybody who's ever seen it.
John Vernon was always hired to be heartless,
regardless of whether he was playing a mayor
or a gangster or a teacher.
"Fat, drunk, and stupid is no way to go through life, son."
-Ah! Dean Warmer in "Animal House."
-Yes, that's right,
and that's actually one of the most famous lines
in movie history.
But he was also in another movie with one of the most famous lines --
"Go ahead, make my day."
-He was in that? -Yeah.
He was the mayor in "Dirty Harry."
-Actually, the "make my day" scene wasn't in "Dirty Harry."
It was in "Sudden Impact."
-It was? -It was. Yeah.
-Darcy, did you just defeat me on Clint Eastwood trivia?
[Laughter] -Don't feel bad.
We can do some Wes Craven trivia later
and you can catch up with me. -Okay. What -- Wes Craven?
What, are you kidding? -I know, what am I thinking?
-Okay, anyway... -I was just trying to make you feel good.
-Alright, I want to remind you that tonight is
the annual "Last Drive-In" Christmas auction,
where we raise money for five charities
that are getting the heck beat out of them,
and they need help this year.
And this particular part of the show
is dedicated to our charity for the homeless and the poor,
Catholic Relief Services.
They have had their budget wrecked this year.
Why? Nobody knows,
but it's a purely 100% United States agency
that lives by a simple rule.
Their goal is, quote,
"to preserve the sacredness and dignity of human life
from conception to natural death."
And that means they go everywhere in the whole world
where people have lost everything, victims of war
or civil unrest or the refugees,
'cause their homeland doesn't exist anymore
or the place they live is unsafe.
We're talking literally millions of people
that are helped by this agency.
And yes, it is part of the church.
It's related to the church,
but it's also the symbol of a rich nation bending
down to help poor nations.
It was actually started by all the American bishops
during World War II to help the refugees
that were displaced by World War II.
No matter what nation they came from,
they still helped them or which side they were on.
They didn't care.
This organization is based in Baltimore.
They focus on hunger and sickness among displaced people
in more than 100 countries.
And when the rug was pulled out from under them,
massive numbers of families became endangered
and massive numbers of lives became threatened.
So if you can't afford to bid on things in the auction
'cause some of those items in the auction
get bid up pretty high,
you can buy a Christmas special T-shirt for 50 bucks
or for 100 bucks, you get the T-shirt and the hoodie.
Same symbol on the hoodie.
And for 150 bucks,
you get the T-shirt, the hoodie,
and the biggest dang cup ever made.
This thing is humongous. I never saw a cup --
This thing is 64 ounces and it's got
the Cold, Cruel Christmas logo on the side
that is half a gallon of liquid in your personal cup.
And you know,
or just for your reference,
you could get five Lone Stars into that one cup,
but then you would still have four ounces left over.
So I need to ask the high sheriffs around.
Matt, you did this cup. Why is this cup only 64 ounce?
You could have added eight ounces, gone for a 72 ounce cup,
and then it would hold an entire six pack.
Why didn't you just go for the six pack, you know?
How were you calibrating this thing?
Or maybe you were going by Tall Boys.
I'm gonna do that --
I'm gonna do that math in my head.
Tall Boy is 16 ounces. Okay.
Alright, I get that.
The cup holds exactly four Lone Star Tall Boys.
You know, they do make a 24 ounce Lone Star in a can.
Have you seen those mothers?
They call those, those aren't Tall Boys,
those are Big Boys. They call those Big Boys.
But those don't make sense for the cup,
'cause that'd just be two Big Boys
and then two thirds of the third Big Boy.
So after you filled up, you'd have to --
you'd have to chug eight ounces right away
before you ever started drinking out of that cup,
so that you wouldn't waste any Big Boy Lone Star. -Mm-hm.
-Anyway, what would you put in the 64 ounce cup, Darcy?
Cotton candy vodka or something like that?
-That's a lot of vodka. Maybe water? Honestly.
-What?! Darcy! -What?
-You can't put water. That's so boring.
How can you even say that? It's a festive cup.
It's a party cup. You can't put water in it.
-I can put festive water in it with no ice.
-You cannot drink 64 ounces of water.
-Yes, I can.
-At least make it Evian
or San Pellegrino or Perrier or something.
-Okay. If that makes you feel better.
-You can't put normal water in the Last Drive-In Christmas Cup.
-Okay. It's Evian. Done.
Is there really a 24 ounce Lone Star in a can?
-It's a Texas beer, Darcy, yes, there is.
Okay. [Laughter]
I promised a little background on John Vernon.
I'm gonna talk about the other actors later,
but John Vernon was born in a tiny hamlet in Saskatchewan
in 1932, so he was older than the rest of the cast.
He'd already had quite a career by the time this movie came out.
He'd worked for Hitchcock, George Cukor, Don Siegel,
but it all started back in Zehner, Saskatchewan,
where he had terrible childhood acne.
And so he discovered that when you're an actor on stage,
you get to cover up the acne with makeup.
And of course, later in life,
the scars on his face would become part of his trademark.
But it was that insecurity
that led him to the Banff School of Drama in Alberta,
and then he ended up winning a scholarship
to the Royal Academy of Dramatic Art in London,
where he was in a class with Peter O'Toole,
Albert Finney, Alan Bates,
and for the rest of his life he would jump between England,
Canada, the US and Italy, doing a lot of film and TV work.
He would sometimes be in 10 or 12 films in a single year,
but also working on the stage and doing voice work.
He had a hit TV series in Canada in the late '60s.
"Wojeck." He played a crusading coroner,
and it was really the first forensic science series
in England or Canada or the US, much imitated series.
He was in an acclaimed play on Broadway,
"The Royal Hunt of the Sun."
He played the explorer De Soto.
Christopher Plummer played Pizarro.
He's the guy who betrays Lee Marvin in John Boorman's
great thriller "Point Blank."
He's a Cuban guerrilla fighter in Hitchcock's "Topaz,"
and he was a great comedian.
Besides Dean Wormer, he was Mr. Big in "I'm Gonna Git You Sucka."
He was Officer Mooney in "Killer Klowns from Outer Space."
-Nice. -And in "Ernest Goes to Camp,"
he's that ruthless mining executive
trying to destroy Kamp Kikakee. -Okay.
-He was the principal in "Savage Streets,"
the warden in "Chained Heat,"
and he played four different characters
on episodes of "Cannon." -Whoo!
-[laughs] Yeah, "Cannon" fan.
Three different characters on episodes of "Mannix."
"Cannon" was obviously an easier show,
you know, get away with that. -What?!
-And he was the first Iron Man.
He played Tony Stark on the Marvel TV series
and then again in 13 episodes of "Captain America."
But anyway, for this role in "Curtains,"
he and director Richard Ciupka
were trying to channel Klaus Kinski.
I don't think Ciupka told him this,
but Klaus Kinski was the original choice for the role
and they had the money for that.
They had 4 million Canadian dollars to work with,
which would be $3.4 million in American money,
because the producers of this movie
had just scored a huge hit.
When they first started filming,
they had been the producers of "Prom Night,"
but would lightning strike twice?
Let's find out as "Curtains" continues.
So roll the film.
Ah, you know...
There are directors and acting teachers like John Vernon
in this movie, especially in New York.
There's some mean dudes at those acting studios.
And you do a 20 minute scene in class,
you're crying, you're feeling it.
You're nailing every line,
you're breathing hard, and the teacher just goes,
"I don't believe you."
"Next." You know.
You know, the only teachers more brutal than acting teachers
is dance teachers.
You know, those ballet ladies.
They yell at ten year old girls.
You know, "You can't do that step
because you got fat over spring vacation!"
"Again, again, again, again!"
You know? They said they're doing that to make you better,
make you stronger, you know, whatever.
But they enjoy it a little too much, you know.
But anyway, "Mannix" is better than "Cannon."
-No way.
-It's too bad we can't ask John Vernon,
which is the better show, "Mannix" or "Cannon"?
'Cause he died in 2005.
-Aww. -I know. Too soon.
We salute you, John, on this Cold, Cruel Christmas.
Because you were the coldest and you were the cruelest.
[Harmonica music]
-Big Briggs!
Reporting in for holiday do-goodery duty.
I got the gift buying opportunities you need
to not totally biff your extended family
Christmas potluck.
Aunt Miriam can't complain
that you got her citronella candles three years in a row,
and she needs them.
"The bugs are biting me 'cause I'm so sweet."
Get real, woman, you got fleas!
Are you looking for fine western jewelry
for the gentleman cowpoke making sweet spittoon music
in your homestead or corral?
Well, saddle up, Sally,
'cause here's your Christmas bull's eye.
Fancy bolo ties, the neckwear of champions.
Screen-used by yours truly.
Get a load of these sexy beasts. Look at that shine.
Ultra gloss, mega gloss. On a clear day,
these stunners will make an impression
from at least 300 yards away on level ground guaranteed.
Also still in stock is this fantastic,
anatomically accurate werewolf mask with genuine synthetic fur
and articulated chomping action.
I hate to see it go.
[Chomping]
But in the spirit of the season, one lucky son of a gun
is walking away with the best damn lycanthrope mask
purchasable at Party City before it went belly up.
We call that "Vintage"!
And hey, bid on both items
and you're ready to recreate one of the timeless
line dancing scenes from "Howling VII."
[Howling]
[Howling continues]
-And them's the facts, Jack.
-Visit us on the web at coldcruelchristmas.com.
♪
[Ice cracking]
[Static buzzes]
[Thunder rumbling]
[Windshield wipers beating]
-The cold weather should continue
with a good chance we'll see some snow before it's over.
So find somebody warm and dig in.
[Cassette plays Burton Cummings' " You Saved My Soul ]
♪ 'Cause you saved my soul ♪
[Vehicle rumbling]
♪ My heart And babe that's something ♪
[Thunder rumbling]
[Tires squeal]
[Windshield wipers beating]
♪
♪
♪
♪
♪
♪
♪
♪
[Screams]
♪
♪
[Car door slams]
[Tires screech]
[Screams]
-Peter?
Peter?
Peter?
[Heavy breathing]
Come on, Peter, no more games, huh?
[Gasps]
[Screams]
[Attacker growls] Aah!
♪
[Body thuds]
[Haunting tones]
♪
-I first read the book when I was a little girl.
It was so beautiful.
Do you know it?
-I am Audra.
I am Audra.
I'm not Audra.
I am Audra.
I am Audra.
I'm not Audra.
[Birdsong]
-Uh, that's 10.25, lady.
-Well, it's here somewhere.
-Maybe you can work it off.
-I like older men, you know. 14, 15.
Hold this please.
-Are you a writer?
-No, actress.
-Yeah, I thought I'd seen you on TV before.
-Not a chance. I woulda remembered you.
-Where are you headed?
-Jonathan Stryker's place. You know it?
-Yeah. Just follow the road up the hill.
Say, do you know Miss Sherwood?
-Samantha Sherwood?
I've heard of her.
God, she was great. Still is, I guess.
-Thanks.
-Thanks.
[Engine rumbles]
♪
♪
-Are we really all here for the same part?
-He obviously doesn't know what he wants.
-What could we all possibly have in common?
-Sex?
[Laughter]
-I mean, we're all women.
-[Laughing] You could've fooled me.
[Laughter]
-Aren't you Brooke Parsons?
-Yes, I am.
-The rest of us might as well pack it in right now.
-What are you doing here?
-I'd kill for the part.
-I'd fuck for it. [Laughter]
-Don't much want the part, huh?
[Laughter]
-What would you do for it?
-Oh, I don't know, uh...
Tell a few jokes.
Do a little song and dance.
Sell my mother into slavery. [laughs]
Go down on him.
[Laughter]
-That shouldn't be necessary --
but I'll keep it in mind.
One of you is missing.
I trust you'll keep us amused, O'Connor.
Parsons. I've long admired your work.
Sommers, hello.
DeMillo --I look forward to hearing you perform.
DeMillo is a musician.
Burns -- you bring your skates?
-Yes. -Good.
This is Matthew.
and one of you is Audra.
Which one?
I don't yet know.
The next two days will be unlike any you've ever known.
Not all of you will make it,
but I promise each of you
will have learned something
about themselves and their craft.
-For all the good it will do you.
-We missed you at dinner.
Ladies, may I present Samantha Sherwood,
an actress I've known for some time.
You may remember her work.
Samantha, may I introduce --
-No, don't bother darling.
They all look alike to me.
Well, Stryker,
is this your idea of a casting session?
-Are you going to play, Samantha?
-You know I am.
[Animal calls]
[Woman's laugh nearby]
-Aah! [Laughing]
♪
[Tara laughing]
-Hey! [Tara laughs]
♪
-It's like old times, isn't it, Samantha?
-You haven't changed a thing, Stryker.
It's exactly as I left it.
-Why are you here?
-Why have you brought those girls here?
-Forget it, Samantha.
Perhaps once you were Audra. Today... [Chuckles]
-But I bought you the rights to "Audra."
-For which I am grateful.
-It was for us.
-Not anymore.
-"Come on. You know I like you."
"Well..." "Come on, just once.
Come on." "No, I don't!"
"Come on. Okay?"
"Well...
Okay."
"Oh! Oh, boy! You give great head." [laughs]
-Gross.
-Wee bit past your bedtime, isn't it, darling?
-Oh. [chuckles]
Has, um, has anyone seen my skates?
I can't seem to find my new pair.
-The girl thinks she's on holiday.
-Oh, no. It's bad for your wind.
I'm still in training.
God knows why. I get up every morning at dawn to practice.
-Dawn? -"I bet you're fun on dates."
-It makes me feel good.
Guess you gotta want it more than being loved.
Isn't that how you feel about acting?
-It depends on the love.
[Laughter]
-I suppose.
Well, I'll, uh, see you in the morning.
-You don't like her?
-What's she doing here? She's just a baby.
-You nervous, too?
-Me?
I'm scared to death.
-But you've been doing this for years.
I-I can remember seeing you in...
-I started early.
It never gets easier.
-Well, there's always the casting Jacuzzi.
-What?
[Tara laughing]
-It's like the casting couch --
only wetter.
-Samantha: I won't give up.
-Stryker: Spare me the melodrama.
-Samantha: If it wasn't for me, you wouldn't even have a project.
-Stryker: I'd find something. -Samantha: Oh, you're a hypocrite.
And a liar.
You never intended to get me out, did you?
-Stryker: I did what I thought was best for everyone involved.
-Samantha: Deserting me in an asylum?
-Stryker: It was your idea to commit yourself.
-Samantha: But not forever.
-Stryker: I'm not convinced you're cured yet.
-Samantha: Oh, Stryker, I was never insane.
-Stryker: Perhaps I should call the good doctor,
let him know where you are.
I suspect he'd be most interested.
-Samantha: Well, I'll tell him the truth.
-Stryker: And I'll deny everything.
And you, my dear, will move back into a rescue manor permanently.
-Samantha: I'll die first!
[Gasps]
-I was just passing by and I heard voices.
-Come in, my dear. Come in.
What you heard is a scene I wrote many years ago for a play.
-Samantha: A very bad play. -A very bad play indeed.
Saved only by your talent and beauty, Samantha.
-A play? You mean it was all a joke?
-Well, let's call it a performance.
-But it sounded so real.
-Tricks of the trade, my dear. Tricks of the trade.
Give the people what they want to believe in.
It's part of our profession.
-But how did you know I was standing outside the door?
-Well, it seems I've developed a sixth sense.
♪
♪
♪
♪
♪
♪
[Metal grinding]
♪
[Grinding continues]
♪
♪
♪
♪
♪
♪
♪
[Static buzzes]
♪
-Okay. Eagle-eyed observers will have noticed
that the credited director on this movie is Jonathan Stryker,
and Jonathan Stryker is also the name
of the character played by John Vernon.
And no, John Vernon did not direct the movie.
What happened is Peter Simpson, a well-known Canadian producer,
hired a cinematographer named Richard Ciupka.
I said Ci-up-ka before, but it's Chu-pka.
He hired him to direct "Curtains" and Ciupka,
he was happy running camera,
and he never thought about directing until Simpson
suggested it, but he figured he should take the opportunity.
And then after they finished the movie,
Simpson said they needed reshoots,
but he did not want Ciupka to come back for reshoots.
He just did 'em himself.
And it turns out that Simpson reshot half the movie,
and he added scenes that Ciupka didn't know about,
and he generally added to his reputation
of being the most meddling producer
who ever walked onto a set.
In fact, he had a reputation for firing directors.
He was an old school, cigar chomping,
larger than life type who could be cruelly blunt.
He would tell actors how bad their acting was.
He would tell directors like Ciupka
that they should choose another line of work.
Stuff like that.
So one of the Directors Guild rules
is that if any changes are made to a movie
after you've left the movie,
the finished movie has to be sent
to the original director for approval.
And when Ciupka saw the changed version,
he refused to put his name on the movie.
Now, normally this would result
in the director being listed as Alan Smithee.
All Alan Smithee movies are American films
with the director's name removed.
But since this was a Canadian film,
Simpson was not limited to the Alan Smithee name.
So he just used the film character's name.
Ciupka's version of the film
was actually completed in the year 1980,
but the film wasn't released until 1983.
Simpson claimed that only 45 minutes of what Ciupka shot was usable,
and he said to everybody who would listen --
"What am I supposed to do with a 45 minute film?"
It's like owning half a car.
So two full years after the original shoot,
he called the cast back for reshoots directed by himself.
He couldn't reassemble the crew
because most of them had other work.
So you'll notice in the end credits there's a chapter one crew
and chapter two crew,
and that's why you may have trouble figuring out
which character is which, because after two years,
hairstyles have changed, faces looked a little different,
and there are way too many brunettes in the cast.
But the main reason Ciupka got fired is the scene
where the actresses are all seated around the dinner table,
and one by one, they're saying what they would do for the part.
You know, "I'd fuck for this part."
You know, "I'd sell my mother into slavery."
You know, jokingly.
But since we know that there's already been one murder,
it's not jokingly for us.
And he was so careful with that shot,
timing the movement of the camera
so that each actress spoke as the pan moved past her face,
that it took most of the day to nail that scene,
and that caused Peter Simpson to say,
"Are you making an art film or a horror film?"
He was really a sort of point-and-shoot,
throw-some-blood-on-it kind of producer.
He was riding high, had his money from "Prom Night,"
and he thought, oh my God, I've hired an artiste from Belgium.
And indeed, Ciupka was a Walloon from the city of Liège in Belgium,
who had immigrated to Montréal with his family at age 14.
And he's trained as a cameraman from the age of 17.
And he got noticed as a camera operator in the film "Angela,"
starring Sophia Loren and John Huston,
and that caught the attention of French director Claude Chabrol
when he came to Montréal in 1977
to make the movie "Blood Relatives"
and, um, Chabrol, he had an interesting rule.
He refused to use any cinematographer
who did not operate the camera himself,
and so Ciupka moved into the director of photography chair
for "Blood Relatives" and then one of the Ilsa movies --
"Ilsa, Tigress of Siberia" --
which also had a French director and most importantly,
the award winning Louis Malle movie "Atlantic City" in 1980.
He was the DP on that.
So Ciupka was so hot after "Atlantic City"
he should have just kept moving
up the cinematography ladder instead of
getting involved with somebody like Simpson.
Because Simpson was correct,
Ciupka was making an artistic horror film,
and sometimes a shot was worth a day or so to get it right.
But anyway, lovers of this movie
and there are many lovers of this movie,
'cause it ran continuously on HBO in the early '90s.
The lovers of this movie study which scenes are directed by Ciupka
and which scenes are directed by Simpson.
And it's a very boring exercise in my opinion.
But my point is that there's nothing wrong
with what Ciupka was doing.
It just wasn't the gore-fest that Simpson wanted.
But we're about to see the difference
between the two directors right now.
That's what I'm talking about it.
Ciupka leaves Christie sobbing in her bed after being casting couched
by Stryker, and then the next morning,
in the sequence that we're about to watch,
she heads out for her morning ice skating regimen,
and Simpson takes over the camera
and he creates his version of an emotional moment.
But before we do that,
I want to remind you that you can go to our website
and buy the T-shirt, the hoodie, the mega cup,
and you can bid on one of the auction items.
And 100% of all that money goes to the charities.
And the charity that we're featuring
in this part of the movie is our annual animal charity.
We always have an animal charity, and this one is
the Xerces Society, based in Portland, Oregon.
And what they do is they try to protect endangered species
that are not as popular as, say, polar bears or anything
'cause they're focused on the invertebrates.
Types of bumble bees and butterflies and grasshoppers
and mussels and fireflies and,
um, many of those species are subject to extinction
because of the use of pesticides,
and probably partly because of their threat
to big agricultural companies,
they have had all their funding slashed.
So save a bug, save a mussel, buy some stuff from us
and do your part.
And now let's watch Lesleh Donaldson, the ice skater,
do her best work.
Lesleh grew up in Toronto.
She became a model at the age of nine.
She got into the Royal Conservatory of Music
'cause her father was a well-known opera singer.
She co-starred at age 14
as Michael Douglas's daughter in the movie "Running."
She starred in a Canadian TV movie called "Homecoming."
She did a very well received after school special
as a girl with epilepsy who joins the swim team.
The movie was called "On My Own."
But as she was making this movie,
she was also suffering from body dysmorphic disorder,
which is where you become depressed by perceived flaws
in your appearance.
And while that was going on
and she was rehearsing her skating moves,
she had a spill on the uneven ice of that pond,
and she cut her chin right before her big scene,
which made everything worse.
You wouldn't know it, though, 'cause it's one of the most
memorable scenes in horror history.
It's frequently cited as a perfect melding
of cinematography, music, and editing, so roll it.
[Harmonica music]
-Oh. -Yes.
-Also, I got to mention the screenwriter on this movie,
Robert Guza Jr.
Robert Guza, he wrote the Ciupka version.
He wrote the Simpson version.
He wrote all the stuff in between
to connect the two versions.
And he has no trouble making those kinds
of radical changes in a script
because he was a soap opera writer.
In fact, he was such a great soap opera writer
that he was the head writer on "General Hospital"
from 1984 to 2011,
and wrote more than 2,000 episodes for that show,
while also writing 755 episodes of "Sunset Beach,"
215 episodes of "Loving,"
and 398 episodes of "Santa Barbara."
And Simpson was good friends with Guza and loved his work.
Any producer would be good friends with Guza
'cause he could write stuff at 2:30 in the afternoon,
and it'd be in front of the camera at 2:45 in the afternoon.
He was a producer's dream on any kind of troubled movie,
especially a troubled movie like this one, so, uh...
-You write a lot of, like, at the last minute, like he did.
[Laughter]
-Darcy. -What?
-This guy wrote 4,000 episodes of network TV shows.
Who does that?
-I guess Robert Guza does that.
-And he wrote this upcoming scene,
which, if I'm not mistaken, this scene has no dialogue.
-So it was one page.
-Well... No.
You know what Mark Twain said?
You know, "Sorry to send you such a long letter.
I didn't have time to write a short one."
-I get that. -Okay.
So thank you, Robert Guza, wherever you are,
we salute you for what has got to be the world episodic record.
[Harmonica music]
Big Briggs here with gifts for the cinéaste
or the cinéaste-hole in your life.
First up, feast your eyes and glut your soul on this
once in a lifetime opportunity.
This is the latex creation,
our very own Shane Morton plastered on Spencer Charnas's face
when we showed "Phantom of the Opera."
It is hideous. It is beautiful. It is breathtaking.
Peeled right off of Spencer's handsome mug
right after we stopped filming,
this bust is sure to look great next to Beethoven
on your grand piano or Casio keytar.
And now for something very special.
My actual press pass from the 1990 Cannes Film Festival.
Check it out, man.
I miss the days when a man could step onto La Croisette
with a feathered mullet
and it would turn heads for good reasons.
The winning bidder will also get a hard copy,
apparently with my editor's notes,
of the press release announcing that yes,
this American redneck critic would in fact
be working the promenade.
It was such a big deal they had to issue a warning to the public, I guess.
Get it while it's hot!
-Right across the street from the converted Pizza Hut.
♪
[Ice cracking]
[Static buzzes]
[Ominous music]
♪
♪
♪
♪
♪
♪
♪
♪
♪
[Cassette plays Burton Cummings' " You Saved My Soul ]
♪ We went together ♪
♪ For so long ♪
♪ Ev'ry second record on the radio seemed like our song ♪
♪ How we hurt each other ♪
♪ Baby, baby, it was so wrong ♪
♪ Something in the bottom of my heart ♪
♪ Will keep me holding on ♪
♪
♪ We were lovers ♪
♪ In the young and strong and bold days ♪
♪ Turn them into treasures ♪
♪ Of silver and gold days ♪
♪ Even though we're older ♪
♪ Still nothing like the old days ♪
♪
♪ Something in the bottom of my heart ♪
♪ Will keep me holding on ♪
♪ 'Cause you saved my soul ♪
♪ You came along and took me out of the night time ♪
♪ Yes, you saved my soul ♪
♪ Taught me to fly ♪
♪ And I gave my heart ♪
[Music stops]
[Birdsong]
[Sighs]
[Birds cawing]
-[Tuts] Ugh.
Oh!
♪
♪
Oh.
[Birdsong]
♪
♪
♪
♪
♪
♪
♪
[Gasps]
♪
♪
♪
[Shouting]
[Screaming]
♪
[Screaming]
[Screaming continues]
♪
-Aah! Oh!
♪
[Screaming]
[Grunt, thud]
[Panting]
[Sobbing]
Oh!
[Bird cawing]
[Panting]
Oh!
Oh! [sobs]
[Bird cawing]
[Moaning]
[Bird caws continue]
Oh... [Sobbing]
[Sobbing continues]
[Crying]
♪
[Wet squelch]
♪
[Static buzzes] -And that was not the only time
that Lesleh Donaldson lost her head in a Canadian horror movie.
She was also beheaded in the J. Lee Thompson classic
"Happy Birthday to Me,"
and she had the lead in "Funeral Home,"
for which she was nominated for a Genie Award in 1980,
the Genie Awards being the equivalent
of the Oscars in Canada.
She had practiced her skating for a long time
to be able to do those scenes,
but as I mentioned, she took a fall on the pond ice
and cut her chin,
and so she had to be doubled once the shooting day arrived.
Lesleh Donaldson has done a lot of theater,
especially in Manitoba.
She worked for the famous Circle in the Square
in New York, and she still does Off-Broadway shows.
For those of you just joining us, though,
this is the annual "Last Drive-In" Christmas special,
"Joe Bob's Cold, Cruel Christmas,"
and we're raising money with a charity auction
for the organizations that have been struggling over the past year.
Every year we choose a children's charity,
and the charity this year
is the Elizabeth Glaser Pediatric AIDS Foundation.
And I don't know who could possibly be opposed
to helping women with AIDS or children with AIDS
or babies born with AIDS,
but apparently somebody was,
because all their grants got canceled,
endangering up to 20,000 lives
of people already receiving help, and of course,
making it difficult to get help for people in the future.
This organization was founded in the '80s by Elizabeth Glaser,
who contracted HIV through a blood transfusion,
and then she unknowingly passed it on to her daughter
through breast milk and also to her unborn son,
all without realizing that the disease was there.
It took her almost a decade
and a key meeting with President Reagan,
but she eventually got Congress to fund research and treatment
of mothers and babies with AIDS.
And it is a global crusade.
They have offices all over the world,
but especially in countries where it's a major problem.
And now, after 35 years, the government is saying,
we don't want to do that anymore.
So buy some stuff from us, bid on some auction items.
Let's get behind these people
so they can continue and expand their work.
Okay, I haven't really talked about the top billed star
in the movie, Samantha Eggar.
She was a genuine old school movie star.
She's British.
I think everybody in this movie is either British or Canadian.
But she's not only British, she's from Hampstead in London,
one of the wealthiest upper class neighborhoods.
And so when she does that American accent,
she has to work at it.
Her father was a brigadier general in the Army,
and she spent 11 years of her youth
at a convent boarding school, being taught by nuns.
And then she went to art school, but she didn't like it there.
And she fell into acting more or less by accident,
and attended one of the top tier London acting schools,
and then went more or less
through the normal training route for Brits.
Two years of repertory theater,
one year at Oxford Repertory,
where many young actors get their initial experience,
and then another year at the Royal court,
where many young playwrights get their initial experience.
And then she moved right on to the West End stage
and made her first film in 1962, at the age of 23 in
"The Wild and the Willing"
with Ian McShane and John Hurt,
and then the crime drama "Doctor Crippen"
with Donald Pleasence and Coral Browne,
and then "Psyche 59" with Patricia Neal and Curt Jurgens.
But her breakthrough movie was her first film in America,
William Wyler's "The Collector."
She was the art student held hostage by Terence Stamp,
and that resulted in an Academy Award nomination
right off the bat.
And then lots of leads and lots of hits.
"Doctor Dolittle" with Rex Harrison,
"Walk, Don't Run" with Cary Grant,
"The Molly Maguires."
She was just everywhere in the late '60s,
and then she kind of retired in 1973,
but she would occasionally come out of retirement
to do projects that just sounded like fun.
If you interview Samantha Eggar about her career,
she doesn't remember the plots of any of the movies.
She remembers the offset experiences.
Or at least that's what she talks about.
Unfortunately, she says,
she was so preoccupied with family issues
that she had very few memories at all of "Curtains."
But that actually works for the part,
'cause she seems to be aloof from all the other actresses
who want to be Audra.
One of her fellow cast members
tells the story of one morning in the makeup room.
Wardrobe guy came in with three dresses for her to choose from,
and Samantha Eggar is sitting next to her assistant,
and she just makes a very slight signal with her face.
She doesn't say anything at all, and the assistant says,
"We won't be using any of those three dresses."
[Laughter] Just like that.
Just in a few seconds.
And the wardrobe guy kind of slinks off with the dresses.
That is what they call, I think, a movie star.
Of course, here at The Last Drive-In,
we don't remember Samantha Eggar for "Doctor Dolittle."
We remember her as the star of David Cronenberg's "The Brood"
and the 1972 giallo "The Dead Are Alive,"
and the 1973 psychedelic possession film "A Name for Evil"
with Robert Culp and the vigilante film "The Exterminator"
and "Demonoid" with Stuart Whitman,
plus that episode in the 1977 anthology film "The Uncanny,"
where Donald Pleasence kills his wife
so he can give his mistress Samantha Eggar,
a chance at an acting career.
To give you some indication of how famous she was in England in the 1960s,
when the ITV network would go off the air
at the end of the broadcast day,
the test pattern that you used to test the colors on your TV --
Samantha Eggar's face.
So is that her skating across the icy pond
in the old hag mask,
or is it John Vernon?
Or is it the dude in the hot tub with Tara?
Matthew and Tara frolicking in the outdoor hot tub.
What was the purpose of that whole scene?
I don't even know. Anyway, all will be resolved --
or maybe not -- as "Curtains" continue.
So roll it.
[Harmonica music]
-And, Darcy, what is -- what's with the creepy doll?
-Uh, it's the killer's calling card.
-For the scene we just watched, for the Christie scene.
But wasn't it also in Amanda's dream?
Wasn't it standing in the middle of the highway in a dream?
-It was, yeah. -But that was a dream.
And Christie, that we saw just now, she wasn't dreaming.
So is it a supernatural doll that jumps into reality
and then jumps into dreams like Freddy Krueger?
-No. -How do you know? Had to be.
-The doll was in Amanda's dream
because it was in her bedroom when she fell asleep.
-It was? -Yeah.
-So it was Amanda's doll?
So somebody killed Amanda and stole her doll?
-Maybe? That's my theory.
-And what's Michael Wincott doing in the movie?
What's the purpose of the guy playing Matthew?
What's the purpose of him being in the movie?
-Maybe he's the killer.
-What exactly is that character?
What does he do at John Vernon's house?
He seems to be around all the time.
-He collects firewood and takes care of the snowmobile
and has sex in the hot tub.
-'Cause every country house in Canada
needs a guy to collect firewood and have hot sex in the hot tub.
-Exactly. [Laughter]
-Hello there, friend.
Are you or a loved one experiencing a rut?
Is your inner child drowning in a raging river of obligation?
Do you wake up every morning simultaneously wishing
it was somehow both yesterday and tomorrow?
Well, you need a shot in the arm from Dr. Big Briggs.
Shake up the ordinary by bidding on one of
these two mystery boxes.
What could be inside?
No, really, what's inside?
Both boxes are full of screen- used bits, bobs and doodads
that have been hiding in the background
since we first started this circus.
Could be anything.
Well, anything that, you know could fit in a box.
They say one man's trash is another man's treasure.
But let me tell you,
here at Big Briggs Furniture Outlet and more,
all our garbage is gold!
Really, though.
Really, though, what the hell did you put in this thing?
♪
-Call us toll free.
♪
[Ice cracking]
[Static buzzes]
♪
-Brooke: Has anyone seen Christie?
-She's gone.
She left a note under my doorway this morning.
Apparently, she couldn't handle it.
-I know how she feels.
-How did she get out with the road snowed in?
-Maybe Matthew took her.
-Well, I wonder what changed her mind.
She was perfectly all right last night.
-And then there were four.
-Christie must have had a difficult night.
-Did she? I wouldn't know. -Brooke: Wouldn't you?
-Let's start with you, Parsons.
You're the veteran. [Door opens]
-No. I am.
-This isn't really necessary, Samantha.
-[Chuckles] Oh, but it is.
Obviously.
-I know what you can do.
-Then why are they here?
-Can we talk about this later?
-I don't want to talk. I want to act.
-All right.
Take center stage.
So what the hell are you doing here?
-I am an actress.
-You're an actress? -There's an echo in here.
-Your turn will come.
What makes you think you can act?
-I know I can. -Could. -Can!
-So? Act.
-What? -Act for us.
-I could do a prepared piece.
-I've seen them all before.
You are such a perfect lady.
So beautiful, so refined.
What if you weren't so -- gifted?
How would you act then?
-I don't think -- -Good.
Don't think. Just do it.
Make yourself -- ugly for us.
Can you?
What if your face were different?
It could be one day, you know.
Hideous, repulsive.
Put it on.
Put it on.
[Heavy breathing]
Now seduce me.
No words.
You can make sounds if you like,
but no lines.
No touching.
Just the mask.
Use your eyes...
...your mouth...
...and horrible beauty.
Make me love you.
Make me desire you.
You're beautiful, remember?
You can't be denied.
This is a mask, too.
Are you satisfied?
All right.
Page 58. The seduction scene.
♪
[Snowmobile rumbling]
♪
♪
♪
[Stool scrapes]
-[Gasps] Medics!
You want me to sit there, right?
Right.
[Clears throat]
[Sighs]
Ah! So...
I guess you're wondering why I called you here, right?
Well, doc, you see,
it all started when my mother locked me in the closet.
I was 21 at the time.
You want me to wear the mask?
-No, that's not necessary.
-Too bad. Might be an improvement.
-Mm.
-Oh, boy, this is what you call bombing, right?
-Are you on something?
-Oh, God, don't I wish.
Oh, I'm on nerves, actually.
Sheer raw nerves.
And if we don't get on with this,
I'm liable to break down right before your very eyes.
-Oh, I don't think that's necessary either.
In fact, this whole session isn't necessary.
-What?
-You're a very talented -- -Joke, right?
Good for a laugh, but nothing serious, is that it?
Oh, yeah, tell me something I don't know.
-What makes you think you're right for Audra?
-I'm as right as anybody else you've got here!
I mean, goddammit, you haven't spent five minutes with me
and now you're telling me I'm wrong for the part.
Why? Because I haven't got a staple through my navel
like that centerfold?
Because I wouldn't pirouette into bed with you
and skate on your face?
I mean, what the hell are you looking for anyway?
And what do you want from me?
I mean, who the fuck is Audra anyway?
Ah! You enjoying yourself?
-Showing a little bit of Audra.
[Quietly] You bastard.
-Where's the mask?
-What do you mean?
-What the hell are you up to, Samantha?
-What am I up to?
You bring five totally different girls here
on a bogus casting session for a part
that was mine in the first place.
And you ask me what I am up to?
[Door slams]
♪
-"I wouldn't bother to kill you,
except I'm so looking forward to every last ounce of blood
seeping out of your wretched body.
If I believed in demons, I'd damn your soul forever." [Tap nearby]
"I'd put a stake through your heart,
if only you had one, you bastard!"
[Tapping sound]
♪
♪
♪
[Tapping]
♪
♪
Oh!
[Sighs]
♪
♪
♪
[Gentle music]
♪
♪
♪
♪
♪
♪
♪
♪
♪
-No, no, no, no, no!
You're a man seducing a woman!
Now, forget your sex.
Enter into his imagination. Become one with him.
♪
Use your vulnerability.
♪
♪
♪
♪
[Tapping sound]
♪
♪
♪
♪
[Tapping sound]
♪
♪
[Dramatic music plays]
-[screaming] No!
[Static buzzes]
♪
-Okay. Nice little jump scare there,
with Brooke discovering the severed head of Christie
in the toilet,
showing that the killer has a sense of humor,
or is maybe trying to scare away the actresses
that can't be directly killed.
I think we're supposed to believe
that Brooke is a tough cookie, and that actress,
Linda Thorson, was indeed a tough cookie.
She has been known her whole life as the woman
who replaced Diana Rigg on "The Avengers"
and got the series canceled after one season.
I don't know how you could spend your whole life
on stage and screen and still be remembered
for the first thing you ever did,
but that's how controversial it was
when Linda Thorson went to a casting call,
and she was chosen over 200 other actresses
to play secret agent Tara King on "The Avengers,"
and the audience did not like it.
They wanted Diana Rigg back,
and Linda Thorson took 100% of that heat on that.
I think that experience did factor into her being cast
in this role,
since she's supposedly the embittered veteran.
Anyway, Linda Thorson is Canadian.
She's done more theater than film.
She's won many awards for her Broadway and
Off-Broadway performances.
She was in "The Greek Tycoon," directed by J. Lee Thompson.
She was in the Steven Seagal movie "Half Past Dead."
She worked at all the great British theaters,
the Royal Shakespeare Company, the Old Vic.
She was a scheming matriarch on "One Life to Live" for three years.
Done a lot of television, but she never regained the attention
that she got at the age of 20, in her very first job.
The Linda Thorson role in this movie,
by the way, was originally given to Céline Lomez,
the popular French-Canadian singer.
But Peter Simpson fired her after she shot a few scenes,
and Simpson decided that she couldn't act.
He had seen her in a French language film
and hired her, I guess, based on her incredible beauty.
But then when he heard her voice in English,
he couldn't stand it.
Um, but, you know, it's one thing to fire somebody,
but Simpson would always do it in a public, outspoken way.
You know, he wanted you to know how badly somebody messed up.
So -- really, no need for that.
Um, anyway, as our Christmas auction continues,
I want to talk a little about our charity for the vulnerable
and disenfranchised -- Meals on Wheels.
Now, I think everybody knows what Meals on Wheels does.
They've been doing it since 1954.
It's become a lifeline for elderly people
who are unable to prepare food for themselves,
and they can't afford to order food.
I can't even tell you how many attacks on Meals on Wheels
have been occurring in the past 11 months.
It started with the gutting of the Older Americans Act,
and it continued with all kinds of stopgap measures.
When people rose up to protest because their elderly,
helpless friends couldn't get their food anymore.
And it's a back-and-forth thing
with incredibly deep funding cuts
that are literally starving old people.
I don't know how it works.
I thought things passed by Congress
could not be messed with,
but apparently I'm naive.
So anyway, Meals on Wheels is based in Alexandria, Virginia,
and they need help and we're gonna give them some help.
So bid on an auction item, buy one of our premiums,
buy three of our premiums,
the T-shirt, the hoodie, the giant cup.
Let's do what they did a hundred years ago.
Let's take care of our friends and neighbors
that have been abandoned by their government.
And am I exaggerating, Darcy? -Not at all.
-I don't know how anybody screws with Meals on Wheels.
Anyway, I wanted to mention the actress Sandra Currie.
She's actually listed in the credits as Sandra Warren.
She apparently changed her name,
which is what a lot of actors did
when they made horror films in the '80s.
Sandra is the party girl musician
who frolics in the hot tub with Matthew
and gets her breasts felt up in that truly bizarre scene
of the close up breast fondling with the dancer Laurian,
played by Anne Ditchburn,
very nervously trying to fondle it as Stryker looks on
and gives fondling directions. [Laughter]
Apparently they wanted a close up of a perfect breast
when they did that scene,
so Peter Simpson actually asked for stunt breast volunteers,
and then he had 'em line up so he could examine each breast,
and the breast he chose ended up belonging to a woman
he would end up doing several movies with.
That's Shannon Tweed's breast in the close up. -Oh!
-And they say filmmaking is grueling work.
Alright, let's get back to the movie.
Ah.
So what we have there, Darcy,
is a woman with a fake name and a scene with a fake breast.
And yet we see pretty much 100% of her in that Jacuzzi scene.
What is your position on stunt breasts?
-I feel like the edit always looks bad.
-'Cause you have to cut to just from the neck down.
-Yeah. -So it looks fake.
Have you ever been asked to be the stunt boobs?
-You mean like a body double? Yeah, many times.
And I have been called in for the express purpose
of just upping the boob count. -Really?
-Mm-hm. -Well, the stunt boob worked for Shannon Tweed.
She didn't even have to show both breasts.
One Shannon Tweed breast resulted in a movie career.
Uh, Sandra Currie, on the other hand,
struggled to make it in B-movies.
She was also in "Terror Train,"
the other 1980 Canadian horror flick,
and "Street Justice" in 1987.
But she was out of the business by 1988
and sadly died young in 1996 of toxic shock syndrome,
which is scary stuff.
You remember when women were just dropping
like flies from toxic shock syndrome?
- I do. It was awful.
-If I remember correctly, they were being killed by their tampons.
-Yeah, actually.
-Did the tampon makers go to jail for that?
-I don't think so.
I think people just got millions of dollars in damages.
-Which doesn't help when you're dead.
Very creepy.
Here, insert this into your body.
It's a miracle thing. It's great.
Whoops. Wow. We're sorry.
You know? Burns my bacon, stuff like that.
-It's like a lot of things are burning your bacon tonight.
-Billionaires and billionaire companies are burning my bacon.
They are not high on my list right now.
Yes. -I see that.
-Big Briggs here with a special something-something
for the history buffs still haunting your Christmas list.
Big Briggs Furniture Outlet and More is the only place
where you can get this very historic Zippo
that I discovered at the site of the original drive-in in Camden, New Jersey
during a thorough archaeological survey.
Check out the rust.
Check out the 1933 stamped right on it.
You can smell the history on this thing.
Just stinking with history.
Also up for grabs is this state-of-the-art metal detector
I use to find this sucker.
So you can tell that one hot receptionist at the DMV
that you unearthed it with your own gol-durn hands.
And trust me, she will totally buy it.
And don't forget, it's a Zippo.
So whether it turns out to just be a replica made in 2001
or carbon dating proves it originates from 1933,
this lighter will perform like it was made yesterday.
Bid now and every time you light a decorative candle
or a honey dipped cigar,
you will think the drive-in will never die.
♪
-Now open Tuesdays and Thursdays.
♪
[Ice cracking]
[Static buzzes]
[Brooke's scream echoes] -Brooke?
-[Sobbing] Christie.
-What about her? -She's dead.
-No, you've had a nightmare. -No, I --
-No one is dead.
-But I saw her!
-You're imagining things.
Let me take you to your room.
-No!
-Maybe I should --
-We'll continue later. Come on.
-Please, no...
-There's nothing there.
-Please.
-Come on. -Oh!
[Brooke cries]
-Come on. -No! No, no, no, no!
-Come on. -Please! No!
-What the hell is frightening you?
-Christie. -Christie.
-Don't! Don't go...
[Panicked breathing]
-There's absolutely nothing in there.
Go on, take a look!
[Brooke stammers]
-Don't, please!
There -- in there.
[Sobbing]
[Screaming] No! No!
[Brooke crying]
-Come on.
Come on.
Get a hold of yourself.
[Brooke sobbing]
-Get some rest.
-How is she?
-I don't know, the door's shut.
Stryker's probably trying to calm her down.
-[Laughs] I'll bet.
-Why would she say that?
Christie's dead?
-She's been drinking a lot.
-Yeah, but that doesn't explain Amanda never arriving.
Matthew's disappeared.
I'm scared.
-Well, maybe Brooke is smarter than we think.
-What do you mean?
-Brooke is acting just like Audra.
-Well, yeah, I suppose, but...
Aren't you being a little...
-Cynical? -Yeah.
-Well, all's fair in love.
And auditions.
[Ominous music plays]
♪
♪
♪
♪
♪
♪
♪
♪
-Stryker: It's like old times, isn't it, Samantha?
[Samantha laughing]
Stryker: Audra herself couldn't have done it better.
-Samantha: I thought that doctor was going to go into shock.
-Stryker: Are you going to play, Samantha?
-Samantha: Why have you brought those girls here?
-Stryker: Forget it, Samantha. Perhaps once you were Audra.
Today... [chuckles]
[Glass shatters]
[Gentle piano music plays]
♪
♪
♪
♪
[Music continues, muffled]
♪
♪
[Heavy breathing]
[Piano music continues]
♪
♪
♪
♪
♪
♪
[Dramatic music plays]
♪
♪
-Tell me about Audra.
-What is it you want to know?
-What's she like?
Is she anything like me?
Is she anything like the others?
Can't you tell me?
♪
[Gun fires thrice]
[Window shatters]
[Window shatters]
[Screaming]
♪
-Help!
Patti!
Brooke! Somebody!
[Wind blowing]
[Sobs]
[Wind blowing]
[Engine sputters]
-Damn it! Come on.
Oh, come on!
Matthew!
[Wind howling]
[Static buzzes]
♪
-Wow. Okay.
The bodies are dropping now, aren't they?
That last shot is Matthew dead in the Jacuzzi.
Matthew's only purpose in the movie was to have sex with Tara
in the Jacuzzi and then die in the Jacuzzi, right?
Did John Vernon have a no Jacuzzi clause in his contract?
You know, he's sleeping with all the other actresses.
Why not Tara?
After all, you know, her left breast looks like the breast of Shannon Tweed.
[Laughter]
Is anybody following all this?
-No. Not at all. -Alright.
Who have I not talked about?
Uh, we talked about Tara. She's still alive.
We didn't talk about Deborah Burgess, who plays Amanda.
She's the one with the -- the rape fantasy boyfriend
who never makes it to the house.
She had a very brief film career.
Her regular job was newscasting.
Who else is alive? Anne Ditchburn just got killed.
The ballerina. I love that Martha Graham dance.
Isn't that what it was? Darcy?
-You're asking me what kind of dance she was doing?
-Well, it wasn't Bob Fosse,
wasn't, you know, jazz hands or anything.
It was that kind of expressive stuff
where you twist your spine and, you know,
delicate -- it's Martha Graham, I think.
-Okay. -Anyway, I liked her dance.
A lot of horror critics online say it's a time waster.
I don't think so. I loved it.
Patti is still alive.
Stand up comic.
Uh, Samantha Eggar is still alive, of course.
Patti is played by Lynne Griffin,
who was known for her Shakespeare roles at the time.
Some of the other actresses were fangirling all over her
just 'cause she was in the movie.
She was a Toronto native.
Her father was a high fashion photographer.
Her mama was a talent agent,
so she was working from the time she was a young child.
In fact, she was five years on a kids TV show.
She frequently worked on stage.
She worked in Canadian TV.
She was only 30 when this movie was made,
but she had an extensive resume by that time.
She was not a stand up comic.
That's one of the things she could not do.
But she wrote that stand up routine herself.
And then she tried it out at the most famous comedy club
in Canada, Yuk Yuk's, in the downtown entertainment district.
That is where Jim Carrey and Norm MacDonald and hundreds
of other comedians got their training.
So that was a brave thing to do.
And she did get laughs at Yuk Yuk's.
She said she was terrified, though.
But in the horror world,
and especially in the Canadian horror world,
Lynne Griffin was best known as Claire Harrison
in Bob Clark's "Black Christmas,"
the 1973 movie
that sort of launched the slasher era in Canada.
Claire Harrison was the character who was
suffocated in the plastic garment bag,
and then her body gets tied up
and put in the rocking chair in the attic.
And she's the dead sorority girl
who's still there at the end of the movie.
Alright.
And then I'm gonna repeat this statistic
from the Women's Advocacy Center,
the charity that we're featuring at this point in the evening,
When the Violence Against Women Act
was gutted earlier this year,
the Women's Advocacy Center and other organizations like it
lost 38% of their budgets.
And immediately that meant that 680,000 women and children
were left without support services.
So if there are any women spending Christmas
worried about some guy breaking into the house and hurting 'em,
or hurting their children
'cause the local shelter got closed,
well, coal in the stocking of whoever made that happen.
In the meantime, we're gonna try to fill that gap,
get involved in our charity auction,
buy some of our Last Drive-In stuff.
Uh, Fright Rags, the T-shirt company in Rochester,
our good friends, they make these things for us.
They don't take any profit.
They do the stuff at cost.
So let's get some money over to the Women's Advocacy Center
in Collierville, Tennessee.
They deal with the local abuse victims in Shelby County,
but they also produce that white paper
that's being used to try to force the government
to get back into the protection of women business.
So let's not have any dead girlfriends this Christmas, okay?
Buy a shirt, bid on some auction items.
Let's help out these dedicated women.
So the last thing we saw --
other than Matthew dead in the hot tub,
is Tara running like a scared rabbit out into the snow.
Why does she run out into the snow?
Because Peter Simpson asked Bob Guza
to put a final girl style chase sequence into the movie.
And so, viola,
suddenly we're made aware of an outbuilding
where Jonathan Stryker stores all the props for his movies.
Welcome to indie filmmaking at its finest!
And roll the movie.
[Harmonica music]
You know, I missed "Curtains" when it first came out.
I was trying to watch all the slashers,
and I still missed some of them.
That's how many slashers there were in the '80s,
especially the early '80s.
But I think it might have underperformed
because of the title.
I mean, I get it, "Curtains," meaning it's curtains for you.
But when you just see the one word curtains
you think might be about home decorating or something.
So they should have called it "Curtains For You"
and then everybody would get it.
Stage talk and gangster talk combined,
actors killing one another.
You know, you got to get that across.
-You're overthinking this. -As usual. [Laughter]
-"Curtains," what a great title. -Yay.
-Big Briggs here.
Blasting into your living room
with a tender reminder that Christmas is for the children.
Blessed be the snot-nosed tykes with visions
of sugar plums crumping in their heads.
But what's this?
Were you too busy being a cog
in the Rube Goldberg device called life
that you forgot to tell Santa what
your little gremlin wanted under the tree?
What did you get for sweet little Susie
and her brother Jebediah?
Well, Big Briggs has got your six --
and your ten and two --
with this custom Famous Slashers Playset,
as featured on the Last Drive-In's Slash-tastic Slasher Night.
This custom set of magnetized maniacs,
created in the nostalgic style of a 1960s Colorforms play set,
comes complete with ten fun loving killing machines
and a moody, airbrushed sheet metal backdrop.
Will you stage a bloody rematch between Freddy and Jason?
A recreation of "Scenes from a Marriage"
starring Norman Bates
and the dude from "I Know What You Did Last Summer"?
With the famous slashers play set,
the only limit is the infinite playground
of your child's imagination.
But wait -- Do you hear what I hear?
There's a commotion down by the dock.
The fishes are biting. That's right!
It's the action-packed Piranha motorized game,
custom painted with the blood of innocents.
Look at these vicious little Still snappers.
Never too early to teach your little ones
about the patience and frustration
of a real fishing trip.
♪
♪
[Laughter]
Move over Santa, 'cause
Big Briggs is gunning for your job.
♪
-Happy holidays from
Big Briggs Furniture Outlet and More.
♪
[Ice cracking]
[Static buzzes]
[Wind howling]
[Door creaking]
[Door slams, object clatters]
[Light clicks on]
[Screams]
[Light clicks on]
[Switch clicks]
[Neon hums]
[Switch clicks]
[Door crashes, Tara shouts]
[Neon humming]
[Dramatic music plays]
♪
[Tense music plays]
♪
♪
Oh...
♪
♪
♪
[Dramatic music plays]
[Tara screams]
♪
♪
[Screaming] Help!
Somebody!
[Sobbing]
♪
[Screams]
Help me!
♪
♪
[Groaning]
♪
[Prop slams]
♪
[Object clatters]
♪
♪
♪
♪
♪
[Dramatic music plays]
[Crashes]
♪
♪
[Heavy breathing]
[Tense music plays]
♪
♪
[Dramatic music plays]
♪
♪
[Sobbing]
♪
[Gasps]
Aah! [Sobs]
♪
[Cries]
[Sniffles]
♪
♪
♪
♪
[Gasps]
♪
♪
♪
[Object clanks]
♪
♪
[Gasps]
♪
♪
Oh!
[Object clanks]
[Suspenseful music plays]
♪
♪
[Clinking sounds]
♪
♪
Come on, come on, come on!
♪
-[Heavy breathing]
-[Grunting]
♪
-[Heavy breathing]
♪
-[Panting]
♪
[Grunting]
[Grunting, gasping]
-[Heavy breathing]
-Oh, please.
[Gasping]
[Grunts]
[Sighs]
-[Heavy breathing]
[Footsteps crunching]
♪
♪
♪
♪
♪
♪
♪
♪
[Objects clattering]
-[Sighs]
[Electricity buzzing]
[Buzzing continues]
[Grate clacking]
[Grate clanks]
[Dramatic music plays]
[Screams] No!
No!
No! No!
Oh, no!
[Screaming]
[Screaming continues]
[Object chopping]
-[Heavy breathing]
[Screaming stops]
[Heavy breathing]
♪
♪
[Wind whistling]
[Footsteps approaching]
[Cork pops] -Oh!
[Liquid pouring]
Oh, my -- [Glass shatters]
[Breathing shakily]
-There's plenty more in the refrigerator.
Audra would know how to open a bottle of champagne.
-She would have smashed the bottle against the counter
and drank from the broken neck.
-How do you know?
-It's what I would do.
[Bottle thuds]
-Tsk, tsk, tsk.
Too violent.
-Audra was mad.
-Did you know that I was in an asylum?
-I heard you were sick.
-He thought so.
He left me there.
-Stryker?
-I had myself committed to learn what Audra knew.
-What did you find out?
-That an actress must always be in control.
[Chuckles lightly]
If you know what you're doing, you're doing it wrong.
-That's what Stryker would have said.
-We're the same.
-He would have liked that.
He was fond of disciples. Young pretty ones.
Was?
Where is he?
-Gone.
-He left?
-He's dead.
It wasn't supposed to be like that.
It's all over now.
Go back.
Go back to the acting classes and the dinner theater,
the chorus line, wait tables, be somebody's secretary,
get married, grow old together.
Forget about Audra.
Have I shocked you?
I'm not sorry.
-Tell me what you've done.
-I killed Stryker!
You want to call the police? Go ahead.
I'm not going anywhere.
[Glass thuds]
[Foreboding music plays]
Don't worry.
I won't hurt any of your friends.
-[Chuckles lightly] It's only me.
-What do you mean?
♪
-They're dead, too.
-What?
You?
Why?
[Screams]
-Have you ever wanted something so badly
you'd do anything for it?
Me?
I wanted to be an actress.
[ Crowd laughing, murmuring ]
I mean, I wanted to be in pictures so badly.
I screwed a guy from Fotomat.
[ Laughter ]
You know, when they say "in and out in 24 hours."
He was in and out in 24 seconds.
[ Laughter ]
[ Voice echoing ] Well, I know what you're wondering.
The question is -- Can she? Right?
That's what you're wondering.
Can she make it? I mean, can I act?
Just ask my boyfriend, boyfriend, boyfriend...
Better yet, ask another one, another one...
♪
♪
♪
♪
♪
♪
♪
♪
♪
♪
♪
♪
♪
♪
♪
♪
[Static buzzes] -And so Patti ends up doing stand up for a captive audience.
And I have to say, that is one
of the most inventive slasher endings
of the '80s or any other decade.
The mystery element really pays off for "Curtains."
Um, you don't really know till the last minute
who the killer actually is.
There are actually two killers facing off in that kitchen,
and the younger actress wins as usual.
But all of Patti's efforts are in vain
because now there's nobody to direct "Audra."
The whole cat and mouse sequence in the props building
was one of the last things that they filmed.
Peter Simpson had that set built
so he could add suspense to the end of the film.
And then "Curtains" was released in March of 1983
and bombed at the box office.
But despite Peter Simpson's cruel words about Richard Ciupka
being a crappy director,
he would go on to direct 12 more movies,
most of them in French,
and Peter Simpson would go back to the "Prom Night" franchise
and make three more of those,
uh, including one of your favorites, Darcy,
"Hello Mary Lou: Prom Night II."
-Yeah, which had almost nothing to do with "Prom Night" one.
-And "Prom Night III: The Last Kiss"
had nothing to do with part one or part two,
but Peter Simpson directed number three.
The only time, only other time,
besides this movie when he directed
and he went on to, uh, kill the franchise
with "Prom Night IV: Deliver Us From Evil,"
the one about the psycho priest.
-Ooh, it's not good. -But, uh, Peter Simpson produced
47 movies and TV shows
by the time of his death in 2007.
He was more of the distributor than a producer, though.
He was -- He was sort of like
the Canadian version of Roger Corman.
So what did you think of "Curtains"?
Honest opinion.
-Honest opinion. Okay.
It's -- It's -- It's pretty slow. [Chuckles]
-It's slow. -I like the atmosphere of it.
And the very, very, very end is fun.
And the ice skating sequence is fun.
But honestly, we've had a lot of requests for it,
so I'm glad we get to show it,
even if it's not the most Christmassy movie
that we've ever had.
-You know, the real superstar on the "Curtains" crew
was Robert Paynter, the cinematographer.
He would go immediately from "Curtains"
to "An American Werewolf in London"
and then to "Trading Places," "Superman II,"
"Superman III,"
"Muppets take Manhattan"... -Yeah.
-..."National Lampoon's European Vacation,"
"Little Shop of Horrors,"
and most notably, Michael Jackson's "Thriller."
-Wow. -So, um, anyway.
Can you believe this is our sixth Christmas auction?
-And I've loved every one of them.
It brings people together.
And speaking of bringing people together at Christmas time.
Our mailbag letter.
It's linked to the hit song "Christmas at the Drive-In."
-I hope you're not talking about that movie
"Christmas at the Drive-In," starring Danica McKellar
on The Great American Family Channel.
The Great American Family Channel,
they get the Christmas movies that Hallmark says
are too formulaic.
-Did you watch that one?
-Do you think I watched a Danica McKellar movie
on The Great American Family Channel?
-I wouldn't be surprised.
But anyway, read the letter and I'll explain.
It's from Shane Sturdivant of Baker City, Oregon.
-Okay.
"Hey, JB, got a mystery I'm trying to solve,
and I was hoping you could provide some additional insight.
This is going to sound real goddamn nerdy."
[Laughter] We don't care.
"And you'll probably have to dig deep into
the memory bank on this one.
But there are things in this universe
that man has to know to sleep soundly.
So here goes. I've attached two pictures."
Can we put up the pictures?
Austin, you got em? -Yeah.
-"Rhe first is an autographed poster
from The Third Annual World Drive-In Movie Festival
and custom car rally that you held at the Inwood,
Inwood Theatre in Dallas
back in October of 1984.
It's signed by yourself, Big Steve King, Ed Neil" --
He was the hitchhiker in "Texas Chainsaw" --
"Linda Shayne," uh, Bootsie Goodhead in, uh,
"Screwballs," "and Cherry Dilday."
Oh, my God.
"You told me once that the signature of Cherry Dilday
was that of an actress that you had hired
to portray her at the event."
Cherry Dilday was an ex-girlfriend
that I used to write about every week in my newspaper column.
"But you couldn't recall her name of the actress,
even though it was likely one of the most significant events
in the history of the Drive-In.
But hey, I get it. We're all losing our marbles.
There's no point in crying over a memory leak."
Well, thanks for that, Shane.
"Guess we'll never know.
Close the book. Pull down the shade.
Kill the lights. Right? Well. Maybe not."
In the voice --
"Do this in the voice of Robert Stack,
a-la "Unsolved Mysteries."
[As Robert Stack] "Update!" -Whoo! Good job
"In your review of 'Chained Heat'
for the Dallas Times Herald,
you mentioned that movie Cherry made
in New Orleans 'Mardi Gras Massacre.'
And you say that her last words in the movie
are 'whatever turns you on.'
Well, there is indeed an actress in that movie
who utters that line just before the trollop walloper
sacrifices her to the god ketchup falafel,
and she is in fact a frizzy-haired redhead.
See second attached photo of said victim.
She's credited as 'dancer with monk' on the IMDb.
And I realize we're getting a little
conspiracy Charlie meme here.
I suspect this was a typo,
and that the person meant to type 'dancer with mink,'
which she does indeed wear in the movie
and the supplied photo.
There are other dancers in the flick,
but those characters either get names like one
one was a Playboy Playmate in 1975,
or spoken descriptions, 19-year-old dancer,
that verify who they are and from what I can see,
all the other dancers are accounted for.
Can you help me out here?
Does the name Cathryn Lacey
credited as dancer with monk or mink ring a bell?"
God help me. Yes, it does. That is her.
I recognize that name. What the fuck?
[Laughter]
"Her only other credit is an uncredited role
in Jack Weiss's 'Crypt of Dark Secrets.'
But I didn't see her in there watching on fast forward,
so I don't know.
Lacey's IMDb profile has are listed
as having been born in Dallas, which fits,
but she's probably passed on by now.
You're the only guy who might be able to solve the mystery."
Why would she be passed on by now?
"Help me Joe Bob Wan Kenobi, you're my only hope.
Seriously, I've had this poster for around 15 years,
and it's bugging the hell out of me.
Thanks much.
Shane Sturdivant, Baker City, Oregon."
Wow, this guy found Cherry Dilday.
-And I have her hit record from 1986.
-You have what?
-I have her record.
Can you put it up, Austin?
-Yeah. Take a look at this thing.
-"Christmas at the Drive-In," recorded by Cherry Dilday,
also known as Cathryn L Lacey.
-You are joking. -Oh, I am not.
-A hit record that is attributed to...
-Surely you are familiar with the song
"Christmas at the Drive-In."
-This is an actual record put out by Cherry Dilday,
who we now know was actually an actress named Cathryn Lacey.
-It is indeed, and it is a catchy tune.
♪ Let's eat another nacho ♪
♪ And have another beer ♪
♪ To rhyme with cheer [Chuckles]
[Laughter]
-Okay. -Cherry Dilday.
-Uh, well, Shane, I guess we solved
your lifelong quest to discover the real Cherry Dilday.
But, Cherry, if you're out there, reveal yourself.
-If you haven't passed on.
-If you haven't passed on, send us an e-mail.
Let us know where you are so we can invite you
to the next jamboree or something that we're doing.
-[Laughs]
-Darcy, do people even know what we're talking about?
-No. -Cherry Dilday was --
Let's not even go there, alright.
-She's all over your books
so people can just buy the book and figure it out.
-Oh, yeah, "Joe Bob Goes to the Drive-In"
just -- just got reissued by Dark Horse.
-You're welcome.
I assume that Cherry Dilday in the book
is based on a real woman in your life?
-No comment. Let's move on.
We have lots more Christmas auction
and another Christmas movie.
So for right now, I'm Joe Bob Briggs,
speaking for myself and for Darcy the Mail Girl,
When I say that if people winked in real life
as much as they do in texting,
the world would be a really creepy place.
And the drive-in will never die.
You know, instead of telling a closing joke,
I could-- -Ooh!
-[Laughs] -Go on.
-You know, when I was talking about Lesleh Donaldson,
the actress who played the ice skater,
and I noted she does a lot of theater.
-Yes.
-So she did a play in Canada called
"How Could You, Mrs. Dick?,"
and it was based on a real murder case
in Hamilton, Ontario.
The murder trial in 1946 of Evelyn Dick.
And Evelyn Dick was this beautiful, glamorous socialite
who married a streetcar driver named John Dick.
And about a year after they got married,
uh, some children were hiking on Hamilton Mountain,
and they discovered a human torso.
No head, no arms, no legs, just a torso.
And the police set about trying to identify who it was.
And the only forensic fact that they had to work with
was that the torso only had one testicle.
So they compared the penis and the scrotum on the torso
to the readily available medical records,
and they confirmed it was the torso of John Dick.
And the rest of his body was never found.
So Evelyn Dick was put on trial for murder.
The prosecution put on evidence
of she had multiple sexual affairs during their marriage,
but they could never tie her directly to the murder,
so she got off.
However, when searching her house,
they found a suitcase that contained the body
of a baby boy encased in cement.
And that was Evelyn Dick's son.
And so she eventually went to prison for that murder.
Meanwhile, the case became famous all over Canada,
and it inspired a bunch of books and songs.
And years later, this play called
"How Could You, Mrs. Dick?"
with Lesleh Donaldson as Mrs. Dick.
And it turns out that that title was based
on a schoolyard rhyme in Canada.
And the rhyme went like this --
"You cut off his legs, you cut off his arms,
you cut off his head...
How could you, Mrs. Dick?"
[Laughter]
-Oh, that's really smart. [Laughs]
-Is that the best schoolyard rhyme in history?
[Laughter]
-I think it is. -I think so.
[Laughter]
♪
[Static buzzes]
Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.